#########################
Aldryn FAQ for django CMS
#########################

|PyPI Version| |Build Status| |Coverage Status| |codeclimate| |requires_io|

Aldryn FAQ is an `Aldryn <http://aldryn.com>`_-compatible simple Frequently
Asked Questions (FAQ) application for `django CMS <http://django-cms.org>`_.

It allows you to present categorized lists of frequently asked questions and
their answers.

**Content editors** looking for documentation on how to use the editing
interface should refer to our `user manual`_ section.

**Django developers** who want to learn more about django CMS, as well as
how to install, configure and customize it for their own projects should
refer to the `documentation`_ sections.

.. _user manual: http://aldryn-faq.readthedocs.org/en/latest/user/index.html


======================
Installation & Updates
======================

Please head over to our `documentation`_ for all the details on how to install,
configure and use Aldryn FAQ.

You can also find instructions on `how to upgrade`_ from earlier versions.

.. _documentation: http://aldryn-faq.readthedocs.org/en/latest/how_to/index.html
.. _how to upgrade: http://aldryn-faq.readthedocs.org/en/latest/how_to/upgrade.html


============
Contributing
============

This is a community project. We love to get any feedback in the form of
`issues`_ and `pull requests`_. Before submitting your pull request, please
review our guidelines for `Aldryn addons`_.

.. _issues: https://github.com/aldryn/aldryn-faq/issues
.. _pull requests: https://github.com/aldryn/aldryn-faq/pulls
.. _Aldryn addons: http://docs.aldryn.com/en/latest/reference/addons/index.html


.. |PyPI Version| image:: http://img.shields.io/pypi/v/aldryn-faq.svg
   :target: https://pypi.python.org/pypi/aldryn-faq
.. |Build Status| image:: http://img.shields.io/travis/aldryn/aldryn-faq/master.svg
   :target: https://travis-ci.org/aldryn/aldryn-faq
.. |Coverage Status| image:: http://img.shields.io/coveralls/aldryn/aldryn-faq/master.svg
   :target: https://coveralls.io/r/aldryn/aldryn-faq?branch=master
.. |codeclimate| image:: https://codeclimate.com/github/aldryn/aldryn-faq/badges/gpa.svg
   :target: https://codeclimate.com/github/aldryn/aldryn-faq
   :alt: Code Climate
.. |requires_io| image:: https://requires.io/github/aldryn/aldryn-faq/requirements.svg?branch=master
   :target: https://requires.io/github/aldryn/aldryn-faq/requirements/?branch=master
   :alt: Requirements Status
